@@ -203,7 +203,7 @@ class ApiBase:
 
                     for error in exception_msg['error']:
                         if error['description2'] and 'You do not have permission for API' in error['description2']:
-                            raise InvalidTokenError('The user has insufficient privilege', exception_msg)
+                            raise NoPrivilegeError('The user has insufficient privilege', exception_msg)
 
                     raise WrongParamsError('Error during {0}'.format(api_response['result']['function']), exception_msg)
                 else:
@@ -231,7 +231,10 @@ class ApiBase:
                 parsed_response = parsed_response['response']['errormessage']
 
         if raw_response.status_code == 400:
-            raise WrongParamsError('Some of the parameters are wrong', parsed_response)
+            if 'error' in parsed_response and isinstance(parsed_response['error'], dict) and 'errorno' in parsed_response['error'] and parsed_response['error']['errorno'] == 'invalidRequest':
+                raise InvalidTokenError('Invalid token / Incorrect credentials', parsed_response)
+            else:
+                raise WrongParamsError('Some of the parameters are wrong', parsed_response)
 
         if raw_response.status_code == 401:
             raise InvalidTokenError('Invalid token / Incorrect credentials', parsed_response)
@@ -291,10 +294,10 @@ class ApiBase:
         return response['result']
 
     def post(self, data: Dict):
-        if self.__dimension in ('CCTRANSACTION', 'EPPAYMENT'):
+        if self.__post_legacy_method is not None:
             return self.__construct_post_legacy_payload(data)
-
-        return self.__construct_post_payload(data)
+        else:
+            return self.__construct_post_payload(data)
 
     def update(self, data: Dict):
         '''
