@@ -8,4 +8,4 @@ from .api_base import ApiBase
 class ARInvoices(ApiBase):
     """Class for AR Invoice APIs."""
     def __init__(self):
-        ApiBase.__init__(self, dimension='ARINVOICE', post_legacy_method='create_invoice')
+        ApiBase.__init__(self, dimension='ARINVOICE')
